@@ -52,7 +52,8 @@
 #' # Tidying
 #'
 #' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns `terms`
-#' (the selectors or variables selected).
+#' (the selectors or variables selected), `token` (name of the tokens), 
+#' `weight` (the calculated IDF weight) is returned. 
 #'
 #' @template details-prefix
 #'
@@ -141,11 +142,13 @@ prep.step_tfidf <- function(x, training, info = NULL, ...) {
 
   check_list(training[, col_names])
 
-  token_list <- list()
+  idf_weights <- list()
 
   for (i in seq_along(col_names)) {
-    token_list[[i]] <- x$vocabulary %||%
-      sort(get_unique_tokens(training[, col_names[i], drop = TRUE]))
+    column <- training[, col_names[i], drop = TRUE]
+    vocabulary <- x$vocabulary %||% sort(get_unique_tokens(column))
+    column_dtm <- tokenlist_to_dtm(column, vocabulary)
+    idf_weights[[i]] <- calc_idf(column_dtm, x$smooth_idf)
   }
 
   step_tfidf_new(
@@ -154,7 +157,7 @@ prep.step_tfidf <- function(x, training, info = NULL, ...) {
     trained = TRUE,
     columns = col_names,
     vocabulary = x$vocabulary,
-    res = token_list,
+    res = idf_weights,
     smooth_idf = x$smooth_idf,
     norm = x$norm,
     sublinear_tf = x$sublinear_tf,
@@ -204,35 +207,68 @@ print.step_tfidf <-
 #' @export
 tidy.step_tfidf <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = unname(x$columns))
+    if (length(x$columns) == 0) {
+      res <- tibble(
+        terms = character(),
+        token = character(),
+        weight = double()
+      )
+    } else {
+      res <- purrr::map2_dfr(
+        x$columns, x$res, 
+        ~ tibble(terms = .x, 
+                 token = names(.y), 
+                 weight = unname(.y))
+        )
+    }
   } else {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = term_names)
+    res <- tibble(
+      terms = term_names,
+      token = NA_character_,
+      weight = na_dbl
+    )
   }
   res$id <- x$id
   res
 }
 
 # Implementation
-tfidf_function <- function(data, names, labels, smooth_idf, norm,
+tfidf_function <- function(data, weights, labels, smooth_idf, norm,
                            sublinear_tf) {
-  counts <- tokenlist_to_dtm(data, names)
 
-  tfidf <- dtm_to_tfidf(counts, smooth_idf, norm, sublinear_tf)
+  # Backwards compatibility with 1592690d36581fc5f4952da3e9b02351b31f1a2e
+  if (is.numeric(weights)) {
+    dict <- names(weights)
+  } else {
+    dict <- weights
+  }
+  counts <- tokenlist_to_dtm(data, dict)
 
-  colnames(tfidf) <- paste0(labels, "_", names)
+  tfidf <- dtm_to_tfidf(counts, weights, smooth_idf, norm, sublinear_tf)
+
+  colnames(tfidf) <- paste0(labels, "_", dict)
   as_tibble(tfidf)
 }
 
-dtm_to_tfidf <- function(dtm, smooth_idf, norm, sublinear_tf) {
+dtm_to_tfidf <- function(dtm, idf_weights, smooth_idf, norm, sublinear_tf) {
   dtm <- normalize(dtm, norm)
 
   if (sublinear_tf) {
     dtm@x <- 1 + log(dtm@x)
   }
-
-  out <- dtm %*% Matrix::Diagonal(x = log(smooth_idf + nrow(dtm) /
-    Matrix::colSums(dtm > 0)))
+  if (is.character(idf_weights)) {
+    rlang::warn(
+      c(
+        "Please retrain this recipe with version 0.5.1 or higher.",
+        "A data leakage bug has been fixed for `step_tfidf()`."
+      )
+    )
+    idf_weights <- log(smooth_idf + nrow(dtm) / Matrix::colSums(dtm > 0))
+    out <- dtm %*% Matrix::Diagonal(x = idf_weights)
+  } else {
+    out <- dtm %*% Matrix::Diagonal(x = idf_weights)
+  }
   as.matrix(out)
 }
 
@@ -252,6 +288,10 @@ normalize <- function(dtm, norm = c("l1", "l2", "none")) {
   Matrix::Diagonal(x = norm_vec) %*% dtm
 }
 
+calc_idf <- function(dtm, smooth) {
+  log(smooth + nrow(dtm) / Matrix::colSums(dtm > 0))
+}
+
 #' @rdname required_pkgs.step
 #' @export
 required_pkgs.step_tfidf <- function(x, ...) {
