@@ -1,7 +1,7 @@
-#' Tokenization of character variables
+#' Tokenization of Character Variables
 #'
-#' [step_tokenize()] creates a *specification* of a recipe step that
-#'  will convert a character predictor into a [tokenlist].
+#' [step_tokenize()] creates a *specification* of a recipe step that will
+#' convert a character predictor into a [`token`][tokenlist()] variable.
 #'
 #' @template args-recipe
 #' @template args-dots
@@ -9,32 +9,32 @@
 #' @template args-trained
 #' @template args-columns
 #' @param training_options A list of options passed to the tokenizer when it is
-#'  being trained. Only applicable for engine == "tokenizers.bpe".
+#'   being trained. Only applicable for engine == "tokenizers.bpe".
 #' @param options A list of options passed to the tokenizer.
 #' @param token Unit for tokenizing. See details for options. Defaults to
-#' "words".
+#'   "words".
 #' @param engine Package that will be used for tokenization. See details for
-#' options. Defaults to "tokenizers".
-#' @param custom_token User supplied tokenizer. Use of this argument
-#'  will overwrite the token and engine arguments. Must take a character vector
-#'  as input and output a list of character vectors.
+#'   options. Defaults to "tokenizers".
+#' @param custom_token User supplied tokenizer. Use of this argument will
+#'   overwrite the token and engine arguments. Must take a character vector as
+#'   input and output a list of character vectors.
 #' @template args-skip
 #' @template args-id
-#' 
+#'   
 #' @template returns
-#' 
+#'
 #' @details
-#' 
+#'
 #' ```{r, echo=FALSE}
 #' options(width = 55)
 #' ```
-#' 
-#' Tokenization is the act of splitting a character string into smaller parts
-#' to be further analyzed. This step uses the `tokenizers` package which
-#' includes heuristics to split the text into paragraphs tokens, word tokens
-#' among others. `textrecipes` keeps the tokens in a [tokenlist] and other
-#' steps will do their tasks on those [tokenlist]s before transforming them
-#' back to numeric.
+#'
+#' Tokenization is the act of splitting a character string into smaller parts to
+#' be further analyzed. This step uses the `tokenizers` package which includes
+#' heuristics on how to to split the text into paragraphs tokens, word tokens,
+#' among others. `textrecipes` keeps the tokens as a [`token`][tokenlist()]
+#' variable and other steps will do their tasks on those [`token`][tokenlist()]
+#' variable before transforming them back to numeric variables.
 #'
 #' Working will `textrecipes` will almost always start by calling
 #' `step_tokenize` followed by modifying and filtering steps. This is not always
@@ -42,20 +42,20 @@
 #' be done with [recipes::step_mutate()].
 #' 
 #' # Engines
-#' 
+#'
 #' The choice of `engine` determines the possible choices of `token`.
 #'
 #' The following is some small example data used in the following examples
-#' 
+#'
 #' ```{r}
 #' text_tibble <- tibble(
 #'   text = c("This is words", "They are nice!")
 #' )
 #' ```
-#' 
+#'
 #' ## tokenizers
-#' 
-#' The tokenizers package is the default `engine` and it comes with the 
+#'
+#' The tokenizers package is the default `engine` and it comes with the
 #' following unit of `token`. All of these options correspond to a function in
 #' the tokenizers package.
 #' 
@@ -72,17 +72,17 @@
 #' * "ptb" (Penn Treebank)
 #' * "skip_ngrams"
 #' * "word_stems"
-#' 
-#' The default tokenizer is `"word"` which splits the text into a series of 
+#'
+#' The default tokenizer is `"word"` which splits the text into a series of
 #' words. By using `step_tokenize()` without setting any arguments you get word
 #' tokens
-#' 
+#'
 #' ```{r}
 #' recipe(~ text, data = text_tibble) %>%
 #'   step_tokenize(text) %>%
 #'   show_tokens(text)
 #' ```
-#' 
+#'
 #' This tokenizer has arguments that change how the tokenization occurs and can
 #' accessed using the `options` argument by passing a named list. Here we are
 #' telling [tokenizers::tokenize_words] that we don't want to turn the words to
@@ -90,118 +90,133 @@
 #' 
 #' ```{r}
 #' recipe(~ text, data = text_tibble) %>%
-#'   step_tokenize(text, 
+#'   step_tokenize(text,
 #'                 options = list(lowercase = FALSE)) %>%
 #'   show_tokens(text)
 #' ```
-#' 
+#'
 #' We can also stop removing punctuation.
-#' 
+#'
 #' ```{r}
 #' recipe(~ text, data = text_tibble) %>%
-#'   step_tokenize(text, 
+#'   step_tokenize(text,
 #'                 options = list(strip_punct = FALSE,
 #'                                lowercase = FALSE)) %>%
 #'   show_tokens(text)
 #' ```
-#' 
+#'
 #' The tokenizer can be changed by setting a different `token`. Here we change
 #' it to return character tokens.
-#' 
+#'
 #' ```{r}
 #' recipe(~ text, data = text_tibble) %>%
 #'   step_tokenize(text, token = "characters") %>%
 #'   show_tokens(text)
 #' ```
-#' 
-#' It is worth noting that not all these token methods are appropriate but are 
+#'
+#' It is worth noting that not all these token methods are appropriate but are
 #' included for completeness.
 #'
 #' ## spacyr
-#' 
+#'
 #' * "words"
 #'
 #' ## tokenizers.bpe
-#' 
+#'
 #' The tokeenizers.bpe engine performs Byte Pair Encoding Text Tokenization.
-#' 
+#'
 #' * "words"
-#' 
+#'
 #' This tokenizer is trained on the training set and will thus need to be passed
-#' training arguments. These are passed to the `training_options` argument and 
+#' training arguments. These are passed to the `training_options` argument and
 #' the most important one is `vocab_size`. The determines the number of unique
 #' tokens the tokenizer will produce. It is generally set to a much higher
 #' value, typically in the thousands, but is set to 22 here for demonstration
 #' purposes.
-#' 
-#' ```{r}
+#'
+#' ```{r, eval=FALSE}
 #' recipe(~ text, data = text_tibble) %>%
 #'   step_tokenize(
-#'     text, 
-#'     engine = "tokenizers.bpe", 
+#'     text,
+#'     engine = "tokenizers.bpe",
 #'     training_options = list(vocab_size = 22)
 #'   ) %>%
 #'   show_tokens(text)
 #' ```
-#' 
+#'
+#' ```{r, echo=FALSE}
+#' recipe(~ text, data = text_tibble) %>%
+#'   step_tokenize(
+#'     text,
+#'     engine = "tokenizers.bpe",
+#'     training_options = list(vocab_size = 22)
+#'   ) %>%
+#'   show_tokens(text) %>%
+#'   lapply(function(x) gsub("▁", "_", x))
+#' ```
+#'
 #' ## udpipe
-#' 
+#'
 #' * "words"
-#' 
+#'
 #' ## custom_token
-#' 
-#' Sometimes you need to perform tokenization that is not covered by the 
+#'
+#' Sometimes you need to perform tokenization that is not covered by the
 #' supported engines. In that case you can use the `custom_token` argument to
 #' pass a function in that performs the tokenization you want.
-#' 
+#'
 #' Below is an example of a very simple space tokenization. This is a very fast
 #' way of tokenizing.
-#' 
+#'
 #' ```{r}
 #' space_tokenizer <- function(x) {
 #'   strsplit(x, " +")
 #' }
-#' 
+#'
 #' recipe(~ text, data = text_tibble) %>%
 #'   step_tokenize(
-#'     text, 
+#'     text,
 #'     custom_token = space_tokenizer
 #'   ) %>%
 #'   show_tokens(text)
 #' ```
 #'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns `terms`
+#' (the selectors or variables selected) and `value` (unit of tokenization).
+#'
 #' @seealso [step_untokenize()] to untokenize.
-#' @family character to tokenlist steps
-#' 
+#' @family Steps for Tokenization
+#'
 #' @examples
 #' library(recipes)
 #' library(modeldata)
-#' data(okc_text)
+#' data(tate_text)
 #'
-#' okc_rec <- recipe(~., data = okc_text) %>%
-#'   step_tokenize(essay0)
+#' tate_rec <- recipe(~., data = tate_text) %>%
+#'   step_tokenize(medium)
 #'
-#' okc_obj <- okc_rec %>%
+#' tate_obj <- tate_rec %>%
 #'   prep()
 #'
-#' bake(okc_obj, new_data = NULL, essay0) %>%
+#' bake(tate_obj, new_data = NULL, medium) %>%
 #'   slice(1:2)
 #'
-#' bake(okc_obj, new_data = NULL) %>%
+#' bake(tate_obj, new_data = NULL) %>%
 #'   slice(2) %>%
-#'   pull(essay0)
+#'   pull(medium)
 #'
-#' tidy(okc_rec, number = 1)
-#' tidy(okc_obj, number = 1)
+#' tidy(tate_rec, number = 1)
+#' tidy(tate_obj, number = 1)
 #'
-#' okc_obj_chars <- recipe(~., data = okc_text) %>%
-#'   step_tokenize(essay0, token = "characters") %>%
+#' tate_obj_chars <- recipe(~., data = tate_text) %>%
+#'   step_tokenize(medium, token = "characters") %>%
 #'   prep()
 #'
-#' bake(okc_obj, new_data = NULL) %>%
+#' bake(tate_obj, new_data = NULL) %>%
 #'   slice(2) %>%
-#'   pull(essay0)
-#'
+#'   pull(medium)
 #' @export
 step_tokenize <-
   function(recipe,
@@ -219,7 +234,7 @@ step_tokenize <-
     add_step(
       recipe,
       step_tokenize_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         role = role,
         trained = trained,
         columns = columns,
@@ -255,7 +270,7 @@ step_tokenize_new <-
 
 #' @export
 prep.step_tokenize <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   training <- factor_to_text(training, col_names)
 
@@ -264,8 +279,13 @@ prep.step_tokenize <- function(x, training, info = NULL, ...) {
   tokenizers <- list()
 
   for (i in seq_along(col_names)) {
-    tokenizers[[i]] <- x$custom_token %||%
-      tokenizer_switch(x$token, x, training[, col_names[[i]], drop = TRUE])
+    text <- training[, col_names[[i]], drop = TRUE]
+
+    if (x$engine == "tokenizers.bpe" & !is.null(x$training_options$vocab_size)) {
+      check_bpe_vocab_size(text, x$training_options$vocab_size, col_names[[i]])
+    }
+
+    tokenizers[[i]] <- x$custom_token %||% tokenizer_switch(x$token, x, text)
   }
 
   step_tokenize_new(
@@ -302,18 +322,18 @@ bake.step_tokenize <- function(object, new_data, ...) {
 #' @export
 print.step_tokenize <-
   function(x, width = max(20, options()$width - 30), ...) {
-    cat("Tokenization for ", sep = "")
-    printer(x$columns, x$terms, x$trained, width = width)
+    title <- "Tokenization for "
+    print_step(x$columns, x$terms, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_tokenize
+#' @rdname tidy.recipe
 #' @param x A `step_tokenize` object.
 #' @export
 tidy.step_tokenize <- function(x, ...) {
   if (is_trained(x)) {
     res <- tibble(
-      terms = x$terms,
+      terms = unname(x$columns),
       value = x$token
     )
   } else {
@@ -362,13 +382,8 @@ tokenizer_switch <- function(name, object, data) {
         "paragraphs", "ptb", "regex", "sentences", "skip_ngrams",
         "tweets", "words", "word_stems"
       )
-
-    if (!(name %in% possible_tokenizers)) {
-      rlang::abort(paste0("token should be one of the supported ",
-        "'", possible_tokenizers, "'",
-        collapse = ", "
-      ))
-    }
+    
+    check_possible_tokenizers(name, possible_tokenizers)
 
     res <- switch(name,
       characters = tokenizers::tokenize_characters,
@@ -392,15 +407,7 @@ tokenizer_switch <- function(name, object, data) {
 
     possible_tokenizers <- c("words")
 
-    if (!(name %in% possible_tokenizers)) {
-      rlang::abort(paste0(
-        "token should be one of the supported ",
-        "'", 
-        possible_tokenizers, 
-        "'",
-        collapse = ", "
-      ))
-    }
+    check_possible_tokenizers(name, possible_tokenizers)
 
     res <- switch(name,
       words = spacyr_tokenizer_words
@@ -413,18 +420,10 @@ tokenizer_switch <- function(name, object, data) {
 
     possible_tokenizers <- c("words")
 
-    if (!(name %in% possible_tokenizers)) {
-      rlang::abort(paste0(
-        "token should be one of the supported ",
-        "'",
-        possible_tokenizers,
-        "'",
-        collapse = ", "
-      ))
-    }
-
+    check_possible_tokenizers(name, possible_tokenizers)
+    
     res <- switch(name,
-      words = tokenizers_bpe_words(data, object$training_options)
+      words = tokenizers_bpe_tokens(data, object$training_options)
     )
     return(res)
   }
@@ -434,15 +433,7 @@ tokenizer_switch <- function(name, object, data) {
 
     possible_tokenizers <- c("words")
 
-    if (!(name %in% possible_tokenizers)) {
-      rlang::abort(paste0(
-        "token should be one of the supported ",
-        "'",
-        possible_tokenizers,
-        "'",
-        collapse = ", "
-      ))
-    }
+    check_possible_tokenizers(name, possible_tokenizers)
 
     res <- switch(name,
       words = udpipe_words(object$training_options$model)
