@@ -47,8 +47,8 @@ test_that("step_tfidf works as intended", {
     as.matrix(manual_answer)
   )
 
-  expect_equal(dim(tidy(rec, 2)), c(1, 2))
-  expect_equal(dim(tidy(obj, 2)), c(1, 2))
+  expect_equal(dim(tidy(rec, 2)), c(1, 4))
+  expect_equal(dim(tidy(obj, 2)), c(17, 4))
 })
 
 test_that("step_tfidf works with vocabulary argument", {
@@ -110,6 +110,52 @@ test_that("can prep recipes with no keep_original_cols", {
   )
 })
 
+test_that("idf valeus are trained on training data and applied on test data", {
+  data <- tibble(text = c("i g", "i i i"))
+  
+  rec <- recipe(~text, data) %>%
+    step_tokenize(text) %>%
+    step_tfidf(text) %>%
+    prep()
+  
+  expect_equal(
+    bake(rec, data %>% slice(1)),
+    bake(rec, data) %>% slice(1)
+  )
+  
+  expect_equal(
+    rec$steps[[2]]$res[[1]],
+    c(g = log(1 + 2 / 1), i = log(1 + 2 / 2))
+  )
+})
+
+test_that("Backwards compatibility with 1592690d36581fc5f4952da3e9b02351b31f1a2e", {
+  # Test that recipes trained with version <= 0.5.0 keep previous behavoir and
+  # throw warning about the data leakage.
+  
+  data <- tibble(text = c("i g", "i i i"))
+  
+  rec <- recipe(~text, data) %>%
+    step_tokenize(text) %>%
+    step_tfidf(text) %>%
+    prep()
+  
+  rec$steps[[2]]$res <- list(c("g", "i"))
+  
+  expect_snapshot(
+    expect_equal(
+      bake(rec, data) %>% slice(1),
+      tibble(tfidf_text_g = log(1 + 2 / 1) / 2, tfidf_text_i = log(1 + 2 / 2) / 2)
+    )
+  )
+  
+  expect_snapshot(
+    expect_equal(
+      bake(rec, data %>% slice(1)),
+      tibble(tfidf_text_g = log(1 + 2 / 2) / 2, tfidf_text_i = log(1 + 2 / 2) / 2)
+    )
+  )
+})
 
 test_that("empty selection prep/bake is a no-op", {
   rec1 <- recipe(mpg ~ ., mtcars)
@@ -130,14 +176,24 @@ test_that("empty selection tidy method works", {
 
   expect_identical(
     tidy(rec, number = 1),
-    tibble(terms = character(), id = character())
+    tibble(
+      terms = character(),
+      token = character(),
+      weight = double(),
+      id = character()
+    )
   )
 
   rec <- prep(rec, mtcars)
 
   expect_identical(
     tidy(rec, number = 1),
-    tibble(terms = character(), id = character())
+    tibble(
+      terms = character(),
+      token = character(),
+      weight = double(),
+      id = character()
+    )
   )
 })
 
