@@ -1,5 +1,3 @@
-context("test-tokenize")
-
 library(textrecipes)
 library(recipes)
 
@@ -44,7 +42,7 @@ test_that("tokenization is done correctly", {
 })
 
 test_that("step throws an error if unavaliable tokenizer is picked", {
-  expect_error(
+  expect_snapshot(error = TRUE,
     rec %>%
       step_tokenize(text, token = "wrong") %>%
       prep()
@@ -93,7 +91,7 @@ test_that("arguments are passed using options argument", {
 })
 
 test_that("tokenization errors with wrong engines", {
-  expect_error(
+  expect_snapshot(error = TRUE,
     rec %>%
       step_tokenize(text, engine = "fake") %>%
       prep()
@@ -129,6 +127,46 @@ test_that("tokenization doesn't includes lemma attribute when unavaliable", {
 test_that("printing", {
   rec <- rec %>%
     step_tokenize(text)
-  expect_output(print(rec))
-  expect_output(prep(rec, verbose = TRUE))
+  expect_snapshot(print(rec))
+})
+
+test_that("empty selection prep/bake is a no-op", {
+  rec1 <- recipe(mpg ~ ., mtcars)
+  rec2 <- step_tokenize(rec1)
+
+  rec1 <- prep(rec1, mtcars)
+  rec2 <- prep(rec2, mtcars)
+
+  baked1 <- bake(rec1, mtcars)
+  baked2 <- bake(rec2, mtcars)
+
+  expect_identical(baked1, baked1)
+})
+
+test_that("empty selection tidy method works", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_tokenize(rec)
+
+  expect_identical(
+    tidy(rec, number = 1),
+    tibble(terms = character(), value = character(), id = character())
+  )
+
+  rec <- prep(rec, mtcars)
+
+  expect_identical(
+    tidy(rec, number = 1),
+    tibble(terms = character(), value = character(), id = character())
+  )
+})
+
+test_that("empty printing", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_tokenize(rec)
+
+  expect_snapshot(rec)
+
+  rec <- prep(rec, mtcars)
+
+  expect_snapshot(rec)
 })
